@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2020 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,25 +24,31 @@ import multiprocessing.pool
 import functools
 import urllib.request
 import urllib.error
+import socks
+import logging
+import time
+from typing import Callable
 
 import sabnzbd
 import sabnzbd.cfg
 from sabnzbd.encoding import ubtou
 
 
-def timeout(max_timeout):
-    """ Timeout decorator, parameter in seconds. """
+def timeout(max_timeout: float):
+    """Timeout decorator, parameter in seconds."""
 
-    def timeout_decorator(item):
-        """ Wrap the original function. """
+    def timeout_decorator(item: Callable) -> Callable:
+        """Wrap the original function."""
 
         @functools.wraps(item)
         def func_wrapper(*args, **kwargs):
-            """ Closure for function. """
-            with multiprocessing.pool.ThreadPool(processes=1) as pool:
-                async_result = pool.apply_async(item, args, kwargs)
-                # raises a TimeoutError if execution exceeds max_timeout
-                return async_result.get(max_timeout)
+            """Closure for function."""
+            # Raises a TimeoutError if execution exceeds max_timeout
+            # Raises a RuntimeError is SABnzbd is already shutting down when called
+            try:
+                return sabnzbd.THREAD_POOL.submit(item, *args, **kwargs).result(max_timeout)
+            except (TimeoutError, RuntimeError):
+                return None
 
         return func_wrapper
 
@@ -64,14 +70,35 @@ def addresslookup6(myhost):
     return socket.getaddrinfo(myhost, 80, socket.AF_INET6)
 
 
+def active_socks5_proxy():
+    """Return the active proxy"""
+    if socket.socket == socks.socksocket:
+        return "%s:%s" % socks.socksocket.default_proxy[1:3]
+    return None
+
+
+def dnslookup():
+    """Perform a basic DNS lookup"""
+    start = time.time()
+    try:
+        addresslookup(sabnzbd.cfg.selftest_host())
+        result = True
+    except:
+        result = False
+    logging.debug("DNS Lookup = %s (in %.2f seconds)", result, time.time() - start)
+    return result
+
+
 def localipv4():
     try:
         with socket.socket(socket.AF_INET, socket.SOCK_DGRAM) as s_ipv4:
             # Option: use 100.64.1.1 (IANA-Reserved IPv4 Prefix for Shared Address Space)
-            s_ipv4.connect(("1.2.3.4", 80))
+            s_ipv4.connect(("10.255.255.255", 80))
             ipv4 = s_ipv4.getsockname()[0]
     except socket.error:
         ipv4 = None
+
+    logging.debug("Local IPv4 address = %s", ipv4)
     return ipv4
 
 
@@ -80,13 +107,16 @@ def publicipv4():
     public ipv4 needs special attention, meaning forcing
     IPv4 connections, and not allowing IPv6 connections
     """
+    start = time.time()
     public_ipv4 = None
     try:
         ipv4_found = False
         # we only want IPv4 resolving, so socket.AF_INET:
         result = addresslookup4(sabnzbd.cfg.selftest_host())
-    except (socket.error, multiprocessing.context.TimeoutError):
+    except (ValueError, socket.error, multiprocessing.context.TimeoutError):
         # something very bad: no urllib2, no resolving of selftest_host, no network at all
+        # Or strange DSM problem: https://github.com/sabnzbd/sabnzbd/issues/2008
+        logging.debug("Failed to detect public IPv4 address")
         return public_ipv4
 
     # we got one or more IPv4 address(es), so let's connect to them
@@ -115,6 +145,8 @@ def publicipv4():
 
     if not ipv4_found:
         public_ipv4 = None
+
+    logging.debug("Public IPv4 address = %s (in %.2f seconds)", public_ipv4, time.time() - start)
     return public_ipv4
 
 
@@ -124,6 +156,8 @@ def ipv6():
             # IPv6 prefix for documentation purpose
             s_ipv6.connect(("2001:db8::8080", 80))
             ipv6_address = s_ipv6.getsockname()[0]
-    except socket.error:
+    except:
         ipv6_address = None
+
+    logging.debug("IPv6 address = %s", ipv6_address)
     return ipv6_address
