@@ -24,8 +24,10 @@ import os
 import random
 import shutil
 from pathlib import Path
+import tempfile
 
 import pyfakefs.fake_filesystem_unittest as ffs
+from pyfakefs.fake_filesystem import OSType
 
 import sabnzbd.cfg
 import sabnzbd.filesystem as filesystem
@@ -52,13 +54,13 @@ class TestFileFolderNameSanitizer:
         # They should act the same
         assert filesystem.sanitize_filename("test:aftertest") == filesystem.sanitize_foldername("test:aftertest")
 
-    @set_platform("darwin")
-    def test_colon_handling_darwin(self):
+    @set_platform("macos")
+    def test_colon_handling_macos(self):
         assert filesystem.sanitize_filename("test:aftertest") == "aftertest"
         assert filesystem.sanitize_filename(":aftertest") == "aftertest"
         assert filesystem.sanitize_filename("::aftertest") == "aftertest"
         assert filesystem.sanitize_filename(":after:test") == "test"
-        # Empty after sanitising with darwin colon handling
+        # Empty after sanitising with macos colon handling
         assert filesystem.sanitize_filename(":") == "unknown"
         assert filesystem.sanitize_filename("test:") == "unknown"
         assert filesystem.sanitize_filename("test: ") == "unknown"
@@ -80,7 +82,7 @@ class TestFileFolderNameSanitizer:
 
     @set_platform("linux")
     def test_win_devices_not_win(self):
-        # Linux and Darwin are the same for this
+        # Linux and macOS are the same for this
         assert filesystem.sanitize_filename(None) is None
         assert filesystem.sanitize_filename("aux.txt") == "aux.txt"
         assert filesystem.sanitize_filename("txt.aux") == "txt.aux"
@@ -255,8 +257,7 @@ class TestFileFolderNameSanitizer:
 class TestSanitizeFiles(ffs.TestCase):
     def setUp(self):
         self.setUpPyfakefs()
-        self.fs.path_separator = "\\"
-        self.fs.is_windows_fs = True
+        self.fs.os = OSType.WINDOWS
         # Disable randomisation of directory listings
         self.fs.shuffle_listdir_results = False
 
@@ -438,44 +439,42 @@ class TestCheckMountLinux(ffs.TestCase):
 
 
 @pytest.mark.skipif(sys.platform.startswith("win"), reason="Non-Windows tests")
-class TestCheckMountDarwin(ffs.TestCase):
+class TestCheckMountMacOS(ffs.TestCase):
     # Our faked macos directory
     test_dir = "/Volumes/test/dir"
 
     def setUp(self):
         self.setUpPyfakefs()
-        self.fs.is_macos = True
-        self.fs.is_case_sensitive = False
-        self.fs.path_separator = "/"
+        self.fs.os = OSType.MACOS
         self.fs.create_dir(self.test_dir, perm_bits=755)
         # Verify the fake filesystem does its thing
         assert os.path.exists(self.test_dir) is True
 
-    @set_platform("darwin")
-    def test_bare_mountpoint_darwin(self):
+    @set_platform("macos")
+    def test_bare_mountpoint_macos(self):
         assert filesystem.check_mount("/Volumes") is True
         assert filesystem.check_mount("/Volumes/") is True
 
-    @set_platform("darwin")
-    def test_existing_dir_darwin(self):
+    @set_platform("macos")
+    def test_existing_dir_macos(self):
         assert filesystem.check_mount("/Volumes/test") is True
         assert filesystem.check_mount("/Volumes/test/dir/") is True
         # Filesystem is set case-insensitive for this platform
         assert filesystem.check_mount("/VOLUMES/test") is True
         assert filesystem.check_mount("/volumes/Test/dir/") is True
 
-    @set_platform("darwin")
+    @set_platform("macos")
     # Cut down a bit on the waiting time
     @set_config({"wait_ext_drive": 1})
-    def test_dir_nonexistent_darwin(self):
+    def test_dir_nonexistent_macos(self):
         # Within /Volumes
         assert filesystem.check_mount("/Volumes/nosuchdir") is False  # Issue #1457
         assert filesystem.check_mount("/Volumes/noSuchDir/") is False
         assert filesystem.check_mount("/Volumes/nosuchDIR/subdir") is False
         assert filesystem.check_mount("/Volumes/NOsuchdir/subdir/") is False
 
-    @set_platform("darwin")
-    def test_dir_outsider_darwin(self):
+    @set_platform("macos")
+    def test_dir_outsider_macos(self):
         # Outside of /Volumes
         assert filesystem.check_mount("/test/that/") is True
         # Root directory
@@ -488,9 +487,7 @@ class TestCheckMountWin(ffs.TestCase):
 
     def setUp(self):
         self.setUpPyfakefs()
-        self.fs.is_windows_fs = True
-        self.fs.is_case_sensitive = False
-        self.fs.path_separator = "\\"
+        self.fs.os = OSType.WINDOWS
         self.fs.create_dir(self.test_dir)
         # Sanity check the fake filesystem
         assert os.path.exists(self.test_dir) is True
@@ -615,9 +612,7 @@ class TestListdirFullWin(ffs.TestCase):
     # Basic fake filesystem setup stanza
     def setUp(self):
         self.setUpPyfakefs()
-        self.fs.is_windows_fs = True
-        self.fs.path_separator = "\\"
-        self.fs.is_case_sensitive = False
+        self.fs.os = OSType.WINDOWS
 
     def test_nonexistent_dir(self):
         assert filesystem.listdir_full(r"F:\foo\bar") == []
@@ -756,9 +751,7 @@ class TestGetUniqueDirFilenameWin(ffs.TestCase):
     # Basic fake filesystem setup stanza
     def setUp(self):
         self.setUpPyfakefs()
-        self.fs.is_windows_fs = True
-        self.fs.path_separator = "\\"
-        self.fs.is_case_sensitive = False
+        self.fs.os = OSType.WINDOWS
 
     # Reduce the waiting time when the function calls check_mount()
     @set_config({"wait_ext_drive": 1})
@@ -810,9 +803,7 @@ class TestCreateAllDirsWin(ffs.TestCase):
     # Basic fake filesystem setup stanza
     def setUp(self):
         self.setUpPyfakefs()
-        self.fs.is_windows_fs = True
-        self.fs.path_separator = "\\"
-        self.fs.is_case_sensitive = False
+        self.fs.os = OSType.WINDOWS
 
     @set_platform("win32")
     def test_create_all_dirs(self):
@@ -1154,3 +1145,12 @@ class TestUnwantedExtensions:
             else:
                 # missing extension is never considered unwanted
                 assert filesystem.has_unwanted_extension(filename) is False
+
+
+class TestDirectoryWriting:
+    # very basic test of directory_is_writable()
+    def test_directory_is_writable(self):
+        # let's test on the tempdir provided by the OS:
+        # on Windows, only basic writing testing will be done, and should succeed
+        # on non-Windows, assuming tempdir is not on FAT, full test should happen, and succeed
+        assert filesystem.directory_is_writable(tempfile.gettempdir())
