@@ -86,7 +86,7 @@ class TestSortingFunctions:
                 else:
                     assert guess[key] == value
 
-    @pytest.mark.parametrize("platform", ["linux", "darwin", "win32"])
+    @pytest.mark.parametrize("platform", ["linux", "macos", "win32"])
     @pytest.mark.parametrize(
         "path, result_unix, result_win",
         [
@@ -503,7 +503,6 @@ class TestSortingSorters:
                 "movie_categories": sort_cats,
                 "enable_movie_sorting": enable_sorting,
                 "movie_sort_extra": " CD%1",
-                "movie_extra_folder": 0,
                 "movie_rename_limit": "100M",
             }
         )
@@ -564,7 +563,6 @@ class TestSortingSorters:
                 "movie_categories": "*",
                 "enable_movie_sorting": 1,
                 "movie_sort_extra": " CD%1",
-                "movie_extra_folder": 0,
                 "movie_rename_limit": size_limit,
                 "date_sort_string": sort_string,  # Date
                 "date_categories": "*",
