@@ -80,7 +80,7 @@ def set_config(settings_dict):
 
             # Reset values
             for item in settings_dict:
-                getattr(cfg, item).set(getattr(cfg, item).default())
+                getattr(cfg, item).set(getattr(cfg, item).default)
             return value
 
         return wrapper_func
@@ -95,25 +95,25 @@ def set_platform(platform):
         def wrapper_func(*args, **kwargs):
             # Save original values
             is_windows = sabnzbd.WIN32
-            is_darwin = sabnzbd.DARWIN
+            is_macos = sabnzbd.MACOS
 
             # Set current platform
             if platform == "win32":
                 sabnzbd.WIN32 = True
-                sabnzbd.DARWIN = False
-            elif platform == "darwin":
+                sabnzbd.MACOS = False
+            elif platform == "macos":
                 sabnzbd.WIN32 = False
-                sabnzbd.DARWIN = True
+                sabnzbd.MACOS = True
             elif platform == "linux":
                 sabnzbd.WIN32 = False
-                sabnzbd.DARWIN = False
+                sabnzbd.MACOS = False
 
             # Perform test
             value = func(*args, **kwargs)
 
             # Reset values
             sabnzbd.WIN32 = is_windows
-            sabnzbd.DARWIN = is_darwin
+            sabnzbd.MACOS = is_macos
 
             return value
 
@@ -230,6 +230,8 @@ class FakeHistoryDB(db.HistoryDB):
 
 @pytest.mark.usefixtures("run_sabnzbd", "run_sabnews_and_selenium")
 class SABnzbdBaseTest:
+    driver = None
+
     def no_page_crash(self):
         # Do a base test if CherryPy did not report test
         assert "500 Internal Server Error" not in self.driver.title
